# Module kerala_math
Python module to simulate computation using methods of the Kerala School of Mathematics

## Install
### Latest Release
`pip install kerala_math`

### Current Development Master
`pip install git+https://github.com/kmadathil/kerala_math.git`

## Usage
Please see the sample notebooks are under `notebooks` for examples on how to use this module
1. Convergence of the Madhava Series - [Run On Google Colab](https://colab.research.google.com/github/kmadathil/kerala_math/blob/master/notebooks/Convergence%20of%20the%20Madhava%20Series.ipynb)
2. Comparing Tabular Jya - [Run On Google Colab](https://colab.research.google.com/github/kmadathil/kerala_math/blob/master/notebooks/Computing%20Tabular%20Sines.ipynb)
3. Comparing Various Means of calculating Jya and Sara - [Run On Google Colab](https://colab.research.google.com/github/kmadathil/kerala_math/blob/master/notebooks/Jya%20Series.ipynb)
